[PATCH] krnl386.exe16: Shared libraries have a ".exe" rather than ".dll" file

Martin Payne development at martinpayne.me.uk
Wed Dec 13 04:23:08 CST 2017


extension on Windows < 3.0.

Tested on Fedora 26 x86.

Signed-off-by: Martin Payne <development at martinpayne.me.uk>
---
 dlls/krnl386.exe16/ne_module.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/dlls/krnl386.exe16/ne_module.c b/dlls/krnl386.exe16/ne_module.c
index 70f8a46467..14f8075166 100644
--- a/dlls/krnl386.exe16/ne_module.c
+++ b/dlls/krnl386.exe16/ne_module.c
@@ -788,9 +788,9 @@ static BOOL NE_LoadDLLs( NE_MODULE *pModule )
             /* its handle in the list of DLLs to initialize.   */
             HMODULE16 hDLL;
 
             /* Append .DLL to name if no extension present */
             if (!(p = strrchr( buffer, '.')) || strchr( p, '/' ) || strchr( p, '\\'))
-                    strcat( buffer, ".DLL" );
+                    strcat( buffer, (GetExeVersion16() >= 0x0300) ? ".DLL" : ".EXE" );
 
             if ((hDLL = MODULE_LoadModule16( buffer, TRUE, TRUE )) < 32)
             {
@@ -988,7 +988,7 @@ static HINSTANCE16 MODULE_LoadModule16( LPCSTR libname, BOOL implicit, BOOL lib_
 
         strcpy( dllname, basename );
         q = strrchr( dllname, '.' );
-        if (!q) strcat( dllname, ".dll" );
+        if (!q) strcat( dllname, (GetExeVersion16() >= 0x0300) ? ".dll" : ".exe" );
         for (q = dllname; *q; q++) if (*q >= 'A' && *q <= 'Z') *q += 32;
 
         strcpy( q, "16" );
@@ -788,9 +788,9 @@ static BOOL NE_LoadDLLs( NE_MODULE *pModule )
             HMODULE16 hDLL;
 
-            /* Append .DLL to name if no extension present */
+            /* Append .DLL (Windows >= 3.00) or .EXE (Windows < 3.00) to name if no extension present */
             if (!(p = strrchr( buffer, '.')) || strchr( p, '/' ) || strchr( p, '\\'))
-- 
2.15.1.windows.2




More information about the wine-devel mailing list